pub fn run<I: BufRead>(
file_name: Option<&str>,
input: &mut I,
) -> Result<(), Error>Expand description
Set up the terminal and run the text editor. If file_name is not None,
load the file.
Update the panic hook to restore the terminal on panic.
Errors
Will Return Err if any error occur when registering the window size signal
handler, enabling raw mode, or running the editor.